unit Sample;
(*
 This sample unit is part of Form Converter package
 Copyright 1999 by Demian [demian@gold.com.br]
*)

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Buttons, ExtCtrls;

type
  TOCHOrientation = (Horizontal,Vertical);
  TForm1 = class(TForm)
    MyComp: TPanel;
    BitBtnOk: TBitBtn;
    BitBtnCancel: TBitBtn;
    BitBtnHelp: TBitBtn;
    procedure BitBtnOkClick(Sender: TObject);
    procedure BitBtnCancelClick(Sender: TObject);
    procedure BitBtnHelpClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    { Private declarations }
    FButtonsSpacing: integer;
    FOrientation: TOCHOrientation;
    procedure SetOrientation(const Value: TOCHOrientation);
    procedure SetButtonsSpacing(const Value: integer);
    procedure RedrawPanel;
  public
    { Public declarations }
  published
    property ButtonsSpacing: integer read FButtonsSpacing write SetButtonsSpacing default 4;
    property Orientation: TOCHOrientation read FOrientation write SetOrientation default Vertical;
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

const
  _Title = 'Form Converter';

procedure TForm1.FormCreate(Sender: TObject);
begin
  FButtonsSpacing := 4;
  FOrientation := Vertical;
  if (csDesigning in ComponentState) then
    MessageBox(0,
               'Sample Component TMyComp'+#13+
               'Copyright 1999 by Demian [demian@gold.com.br]'+#13#13+
               'New properties: ButtonsSpacing/Orientation',_Title,
               MB_ICONINFORMATION);
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  MessageBox(0,'Destroying MyComp...',_Title,MB_ICONEXCLAMATION);
end;

procedure TForm1.BitBtnOkClick(Sender: TObject);
begin
  MessageBox(0,'Button OK',_Title,MB_ICONINFORMATION);
end;

procedure TForm1.BitBtnCancelClick(Sender: TObject);
begin
  MessageBox(0,'Button Cancel',_Title,MB_ICONINFORMATION);
end;

procedure TForm1.BitBtnHelpClick(Sender: TObject);
begin
  MessageBox(0,'Button Help',_Title,MB_ICONINFORMATION);
end;

procedure TForm1.SetButtonsSpacing(const Value: integer);
begin
  FButtonsSpacing := value;
  RedrawPanel;
end;

procedure TForm1.SetOrientation(const Value: TOCHOrientation);
begin
  FOrientation := Value;
  RedrawPanel;
end;

procedure TForm1.RedrawPanel;
begin
  if Orientation = Vertical then begin
    Height := BitBtnOK.Height*3+FButtonsSpacing*4;
    Width := BitBtnOK.Width+FButtonsSpacing*2;
    BitBtnOK.Top := FButtonsSpacing;
    BitBtnCancel.Top := BitBtnOK.Top+BitBtnOK.Height+FButtonsSpacing;
    BitBtnHelp.Top := BitBtnCancel.Top+BitBtnCancel.Height+FButtonsSpacing;
    BitBtnOK.Left := FButtonsSpacing;
    BitBtnCancel.Left := FButtonsSpacing;
    BitBtnHelp.Left := FButtonsSpacing;
    end
  else begin
    Height := BitBtnOK.Height+FButtonsSpacing*2;
    Width := BitBtnOK.Width*3+FButtonsSpacing*4;
    BitBtnOK.Top := FButtonsSpacing;
    BitBtnCancel.Top := FButtonsSpacing;
    BitBtnHelp.Top := FButtonsSpacing;
    BitBtnOK.Left := FButtonsSpacing;
    BitBtnCancel.Left := BitBtnOK.Left+BitBtnOK.Width+FButtonsSpacing;
    BitBtnHelp.Left := BitBtnCancel.Left+BitBtnCancel.Width+FButtonsSpacing;
  end;
end;

end.
